import Link from 'next/link';

function PopularNeighborhoods(){
	const places = ["Ballard Hill", "Beacon Hill", "Beacon Hill", "Belltown", "Capitol Hill", "Central District", "Columbia City", "Downtown Seattle", "Eastlake", "First Hill", "Fremont", "Georgetown", "Green Lake", "Greenwood", "International District", "Lake City", "Leschi", "Madison Park", "Madrona", "Magnolia", "Maple Leaf", "Northgate", "Olympic Hills", "Phinney Ridge", "Pioneer Square", "Queen Anne", "Rainier Valley", "Ravenna", "Roosevelt", "SoDo", "South Lake Union", "University District", "Wallingford", "West Seattle", "Westlake"];
	return <>
		<div className="join join-vertical w-full px-8 md:px-0">
			<div className="collapse collapse-arrow join-item rounded-none border-b border-white/50">
				<input type="checkbox" /> 
				<h1 className="collapse-title text-white ps-1 font-bold">Popular Neighborhoods</h1>
				<div className="collapse-content px-2">
					<h2 className='text-white font-mono text-xl text-center'>Wash &amp; Fold</h2>
					<div className='flex flex-wrap gap-1.5 mt-1.5'>
						{
							places.map((v, k)=>(
								<Link key={k} target='_blank' href={'https://getchoreless.com/seattle/wash-and-fold-laundry-service-in-'+v.toLowerCase().split(' ').join('-')} className="badge badge-neutral bg-opacity-50 hover:badge-info hover:bg-opacity-100 rounded-md">{v}</Link>
							))
						}
					</div>
					<h2 className='text-white font-mono text-xl text-center mt-5'>Home &amp; Bedding</h2>
					<div className='flex flex-wrap gap-1.5 mt-1.5'>
						{
							places.map((v, k)=>(
								<Link key={k} target='_blank' href={'https://getchoreless.com/seattle/home-and-bedding-laundry-service-in-'+v.toLowerCase().split(' ').join('-')} className="badge badge-neutral bg-opacity-50 hover:badge-info hover:bg-opacity-100 rounded-md">{v}</Link>
							))
						}
					</div>
				</div>
			</div>
		</div>
	</>
}

function TopCities(){
	const links =
	<div className='flex flex-wrap gap-1.5 items-center'>
		{
			['Seattle', 'Bellevue', 'Tacoma', 'Kirkland'].map((v, k)=>
				<Link key={k} target='_blank' href='#' className="badge badge-neutral bg-opacity-50 hover:badge-info hover:bg-opacity-100 rounded-md">{v}</Link>
			)
		}
	</div>

	return <>
		{/* phone */}
		<div className="md:hidden join join-vertical w-full px-8 text-white">
			<div className="collapse collapse-arrow join-item rounded-none border-b border-white/50">
				<input type="checkbox" /> 
				<h1 className="collapse-title ps-1 font-bold">Top Cities</h1>
				<div className="collapse-content block px-2"> 
					{links}
				</div>
			</div>
		</div>
		{/* desktop */}
		<div className="hidden md:flex text-white font-medium leading-7 gap-x-2 mt-2">
			<h1 className="ps-1 font-bold">Top Cities <span className='ms-3'>|</span></h1>
			<Link href="#">Seattle</Link>
			<span>|</span>
			<Link href="#">Bellevue</Link>
			<span>|</span>
			<Link href="#">Tacoma</Link>
			<span>|</span>
			<Link href="#">Kirkland</Link>
		</div>
	</>
}

function Company({layout}: {layout: 'phone'|'desktop'}){
	const links = <>
		<Link href="#">Our Story</Link>
		<Link href="/careers">Careers</Link>
		<Link href="#">Blog - Coming soon</Link>
		<Link href="#">FAQs - Coming soon</Link>
		<Link href="#">Privacy</Link>
		<Link href="#">Terms</Link>
		<Link href="#">Cookies</Link>
	</>
	return layout==='phone' ? <>
		{/* phone */}
		<div className="join join-vertical w-full px-8 text-white">
			<div className="collapse collapse-arrow join-item rounded-none border-b border-white/50">
				<input type="checkbox" /> 
				<h1 className="collapse-title block ps-1 font-bold">Company</h1>
				<div className="collapse-content block"> 
					<div className="text-base font-medium underline leading-7 flex flex-col">
						{links}
					</div>
				</div>
			</div>
		</div>
		</>:<>
		{/* desktop */}
		<h1 className="text-white text-lg font-bold leading-snug">Company</h1>
		<div className="mt-5">
			<div className="text-white font-medium underline leading-7 flex flex-col">
				{links}
			</div>
		</div>
	</>
}

function More({layout}: {layout: 'phone'|'desktop'}){
	const links = <>
		<Link href="#">How it works</Link>
		<Link href="#">Cleaning Partners</Link>
		<Link href="#">Hotel Partnerships</Link>
		<Link href="#">Gift Cards</Link>
	</>
	return layout==='phone' ?
	<>
		{/* phone */}
		<div className="join join-vertical w-full px-8 text-white">
			<div className="collapse collapse-arrow join-item rounded-none border-b border-white/50">
				<input type="checkbox" /> 
				<h1 className="collapse-title block ps-1 font-bold">More</h1>
				<div className="collapse-content block"> 
					<div className="font-medium underline leading-7 flex flex-col">
						{links}
					</div>
				</div>
			</div>
		</div>
	</>:<>
		{/* desktop */}
		<h1 className="text-white text-lg font-bold leading-snug">More</h1>
		<div className="mt-5">
			<div className="text-white font-medium underline leading-7 flex flex-col">
				{links}
			</div>
		</div>
	</>
}

function ContactUs({layout}: {layout: 'phone'|'desktop'}){
	const common =
	<>
		<div className="text-base font-medium leading-7 flex flex-col">
			<Link href="tel:(888) 315-0445">(888) 315-0445</Link>
			<Link href="mailto:hello@getchoreless.com">hello@getchoreless.com</Link>
			<p className='mt-2'>Customer care:</p>
			<p className='-mt-2'>Mon - Sun | 9am to 8:00pm</p>
		</div>
	</>
	return layout==='phone' ?
	<>
		{/* phone */}
		<div className="join join-vertical w-full px-8 text-white">
			<div className="collapse collapse-arrow join-item rounded-none border-b border-white/50">
				<input type="checkbox" /> 
				<h1 className="collapse-title block ps-1 font-bold">Contact Us</h1>
				<div className="collapse-content block"> 
					{common}
				</div>
			</div>
		</div>
	</>:<>
		<h1 className="text-white text-lg font-bold leading-snug">Contact Us</h1>
		<div className='mt-5 text-white'>{common}</div>
	</>
}

function JoinMailingList(){
	return <>
		<h1 className="text-white text-2xl font-bold text-center md:text-start">Join our Mailing list</h1>
		<div className="flex flex-col gap-y-4 mt-3 md:mt-5">
			<input type="text" className="input h-10 rounded border" placeholder="Enter your E-mail here..." />
			<input type="text" className="input h-10 rounded border" placeholder="ZIP Code" />
			<button className="btn h-10 rounded-3xl bg-blue-600 text-slate-50 font-bold border-blue-600 hover:bg-transparent hover:border-blue-600 hover:text-blue-600">Subscribe</button>
		</div>
		<div className="mt-6">
			<p className="text-white text-center text-lg font-bold leading-relaxed">Download our App</p>
			<div className="flex justify-center gap-x-2.5 mt-5">
				<img src='https://ik.imagekit.io/choreless/v2/icons/FigmaAppleStore.svg' alt='icon' loading='lazy' />
				<img src='https://ik.imagekit.io/choreless/v2/icons/FigmaPlayStore.svg' alt='icon' loading='lazy' />
			</div>
		</div>
	</>
}

function Bottom(){return (
	<div className="mt-[62px]">
		<div className="flex flex-col items-center sm:flex-row">
			<Link href='/'><img src='https://ik.imagekit.io/choreless/v2/icons/choreless.svg' alt='Choreless' loading='lazy' /></Link>
			<div className="sm:ms-7 md:ms-14 text-xs text-center mt-5">
				<div className="text-white text-[10px] md:text-xs">
					<div className="flex gap-x-1 sm:gap-x-2 justify-center">
						<Link href="#">Terms of Use</Link>
						<span>|</span>
						<Link href="#">Privacy Policy</Link>
						<span>|</span>
						<Link href="#">Sitemap</Link>
					</div>
					<div className="flex gap-x-1 sm:gap-x-2 mt-1">
						<Link href="#">Accessibility Tools</Link>
						<span>|</span>
						<Link href="#">Do Not Sell or Share My Personal Information</Link>
					</div>
					<p className="mt-1">© Copyright 1995-2023, Choreless. All Rights Reserved.</p>
				</div>
			</div>
			<div className="flex gap-x-5 sm:ml-auto sm:me-10 mt-3">
				<Link target='_blank' className='hover:animate-[spin_2s_linear_infinite;]' href='https://www.instagram.com/chorelesslaundry'><img src='https://ik.imagekit.io/choreless/v2/icons/FigmaInstagram.svg' alt='icon' loading='lazy' /></Link>
				<Link target='_blank' className='hover:animate-[spin_2s_linear_infinite;]' href='https://nextdoor.com/pages/choreless-laundry-seattle-wa'><img src='https://ik.imagekit.io/choreless/v2/icons/FigmaNextdoor.svg' alt='icon' loading='lazy' /></Link>
				<Link target='_blank' className='hover:animate-[spin_2s_linear_infinite;]' href='https://www.facebook.com/chorelesslaundry'><img src='https://ik.imagekit.io/choreless/v2/icons/FigmaFacebook.svg' alt='icon' loading='lazy' /></Link>
			</div>
		</div>
	</div>
)}


export default function Footer(){
	return (
		<div className="bg-zinc-900 rounded-tl-3xl rounded-tr-3xl px-0 md:px-8 pb-8 pt-2">
			<div className="max-w-[1180px] mx-auto">
				<div>
					<PopularNeighborhoods />
					<TopCities />
					<div className='md:hidden'><Company layout='phone' /></div>
					<div className='md:hidden'><More layout='phone' /></div>
					<div className='md:hidden'><ContactUs layout='phone' /></div>
				</div>
				<div className="grid md:grid-cols-[2fr_1fr_1fr_1fr] sm:gap-x-4 lg:gap-x-16 justify-center mt-12">
					<div className='md:order-2 hidden md:block'><Company layout='desktop' /></div>
					<div className='md:order-3 hidden md:block'><More layout='desktop' /></div>
					<div className='md:order-4 hidden md:block'><ContactUs layout='desktop' /></div>
					<div className='md:order-1'><JoinMailingList /></div>
				</div>
				<Bottom />
			</div>
		</div>
	)
}
